Getting started — Bombardier v1.00 documentation

### Navigation

- index
- next |
- previous |
- Bombardier v1.00 documentation »
- Bombardier documentation contents »

# Getting started

New to Bombardier? Or to automated server configuration management in general? Well, you came to the right place: read this material to quickly get up and running.

- Quick install guide
- Deploying your first package with Bombardier, part 1
- Deploying your first package with Bombardier, part 2
- Deploying your first package with Bombardier, part 2

See also

If you’re new to Python, you might want to start by getting an idea of what the language is like. Bombardier is 100% Python, so if you’ve got minimal comfort with Python you’ll probably get a lot more out of Bombardier.

If you’re new to programming entirely, you might want to start with this list of Python resources for non-programmers

If you already know a few other languages and want to get up to speed with Python quickly, we recommend Dive Into Python (also available in a dead-tree version). If that’s not quite your style, there are quite a few other books about Python.

### Navigation

- index
- next |
- previous |
- Bombardier v1.00 documentation »
- Bombardier documentation contents »